

#' SpecHelpers: Spectroscopy Related Utilities
#' 
#' Utility functions for spectroscopy.  1. Functions to simulate spectra for
#' use in teaching or testing.  2.  Functions to process files created by
#' LoggerPro and SpectraSuite software. 
#' 
#' @name SpecHelpers-package
#' @aliases SpecHelpers-package SpecHelpers
#' @author Bryan A. Hanson, DePauw University, Greencastle Indiana USA
#' @rdname SpecHelpers-package
#' @title Spectroscopy Related Utilities
#' Maintainer: Bryan A. Hanson \email{hanson@@depauw.edu}
#' @keywords package
"_PACKAGE"
